angular.module('zscy.news', ['ionic', 'zscy.services']);
angular.module('zscy.news')
  .config(function($stateProvider, $urlRouterProvider,templateUrlPath) {
    $stateProvider
      .state('tab.news', {
        url: '/news',
        views: {
          'tab-home': {
            templateUrl:templateUrlPath + 'templates/home/news/news.html',
            controller: 'newsCtrl'
          }
        }
      })
      .state('tab.news_detail', {
        url: '/:news_id/news_detail',
        views: {
          'tab-home': {
            templateUrl:templateUrlPath + 'templates/home/news/news_detail.html',
            controller: 'news_detailCtrl'
          }
        }
      });
  })
  .controller('newsCtrl', ['$scope', '$stateParams', 'newsService', '$ionicModal', '$ionicLoading', '$cordovaDialogs', function($scope, $stateParams, newsService, $ionicModal, $ionicLoading, $cordovaDialogs) {
    $scope.modal = {};
    $scope.news = newsService.getnews();
    $scope.title = '新闻动态';
    $scope.page = 1;
    $scope.size = 10;
    var has_more = $scope.news.length >= $scope.size;
    $scope.hasMore = function() {
      return has_more;
    };
    $scope.refresh = function() {
      newsService.refresh(1, $scope.size)
        .then(function(data) {
          if (data.errcode !== undefined && data.errcode !== 0) {
            $cordovaDialogs.alert(data.errmsg, '温馨提示', '好的');
          } else {
            if (data.length < $scope.size) {
              has_more = false;
            } else {
              has_more = true;
            }
            $scope.page = 2;
          }
          $scope.news = newsService.getnews();
        }, function(error) {
          $ionicLoading.show({
            template: '网络错误',
            duration: 1000
          });
        })
        .finally(function() {
          $scope.$broadcast('scroll.refreshComplete');
        });
    };
    $scope.refresh();
    $scope.doRefresh = function() {
      $scope.refresh();
    };
    $scope.more = function() {
      newsService.more($scope.page, $scope.size)
        .then(function(data) {
          if (data.errcode !== undefined && data.errcode !== 0) {
            has_more = false;
            $cordovaDialogs.alert(data.errmsg, '温馨提示', '好的');
          } else {
            $scope.page++;
            if (data.length < $scope.size) {
              has_more = false;
            }
          }
          $scope.news = newsService.getnews();
          $scope.$broadcast('scroll.infiniteScrollComplete');
        }, function(error) {
          $ionicLoading.show({
            template: '网络错误',
            duration: 1000
          });
        });
    };
    $scope.openModal = function(modal_name) {
      $ionicModal.fromTemplateUrl('templates/modals/' + modal_name + '.html', {
        scope: $scope,
        animation: 'slide-in-up'
      }).then(function(modal) {
        $scope.modal[modal_name] = modal;
        $scope.modal[modal_name].show();
      });
    };

    $scope.closeModal = function(modal_name) {
      $scope.modal[modal_name].remove();
    };

    $scope.removeModal = function(modal_name) {
      $scope.modal[modal_name].remove();
    };

    $scope.submitModal = function(modal_name) {
      $scope.refresh();
      $scope.modal[modal_name].remove();
    };
  }])
  .controller('news_detailCtrl', function($scope, articleService, $stateParams, $ionicModal, $ionicLoading, $ionicHistory, $cordovaDialogs, $ionicScrollDelegate) {
    $scope.modal = {};
    $scope.news = articleService.getInfo();
    $scope.page = 1;
    $scope.size = 10;
    var has_more = $scope.news.length >= $scope.size;
    $scope.hasMore = function() {
      return has_more;
    };
    $scope.refresh = function() {
      articleService.refresh($stateParams.news_id)
        .then(function(data) {
          if (data.errcode !== undefined && data.errcode !== 0) {
            $cordovaDialogs.alert(data.errmsg, '温馨提示', '好的');
          } else {
            if (data.length < $scope.size) {
              has_more = false;
            } else {
              has_more = true;
            }
            $scope.page = 2;
          }
          $scope.news = articleService.getInfo();
        }, function(error) {
          $ionicLoading.show({
            template: '网络错误',
            duration: 1000
          });
        })
        .finally(function() {
          $scope.$broadcast('scroll.refreshComplete');
        });
    };
    $scope.refresh();
    $scope.doRefresh = function() {
      $scope.refresh();
    };

    $scope.openModal = function(modal_name) {
      $ionicModal.fromTemplateUrl('templates/modals/' + modal_name + '.html', {
        scope: $scope,
        animation: 'slide-in-up'
      }).then(function(modal) {
        $scope.modal[modal_name] = modal;
        $scope.modal[modal_name].show();
      });
    };

    $scope.closeModal = function(modal_name) {
      $scope.modal[modal_name].remove();
    };

    $scope.removeModal = function(modal_name) {
      $scope.modal[modal_name].remove();
    };

    $scope.submitModal = function(modal_name) {
      $scope.modal[modal_name].remove();
      //TODO
    };

    $scope.showImg = function(url) {
      $scope.openModal('show_img');
    };
  });
