angular.module('zscy.directives', ['zscy.services']);
angular.module('zscy.directives')

.directive('lsRepeat', function() {
  return {
    restrict: 'A',
    transclude: true,
    replace: true,
    compile: function(element, attr) {
      var expression = attr.lsRepeat;
      var match = expression.match(/^\s*([\s\S]+?)\s*$/);
      if (!match) {
        return console.error('lsRepeat发生错误');
      }
      var len = match[1];
      return function(scope, element, attr) {
        scope.$watch(len, function(cv, ov) {
          //初始元素周围不能存在其他tagName相同的元素
          if (cv > 0) {
            element.removeClass('ls-hide');
            element.parent().find(element[0].tagName).next().remove();
            for (var i = 0; i < cv - 1; i++) {
              element.after(element.clone());
            }
          } else {
            element.addClass('ls-hide');
          }
        });
      };
    }
  };
})

.directive('lsStar', function() {

  return {
    restrict: 'E',
    replace: true,
    templateUrl: 'templates/directives/star.html',
    require: '?ngModel',
    link: function(scope, element, attr, ngModel) {
      if (!ngModel) return;

      scope.clickStar = function(star) {
        scope.star = star;
        ngModel.$setViewValue(star);
      };
    }
  };
})

.directive('lsMap', function() {

  return {
    restrict: 'E',
    replace: true,
    templateUrl: 'templates/directives/map.html',
    link: function(scope, element, attr) {
      var latitude = parseFloat(attr.latitude);
      var longitude = parseFloat(attr.longitude);
      var el = element[0];
      //el.style.height = element[0].parentNode.clientHeight + 'px';
      var map = new BMap.Map(el);
      map.disableDragging();
      map.disableScrollWheelZoom();
      map.disableDoubleClickZoom();
      map.disablePinchToZoom();
      map.addControl(new BMap.NavigationControl({
        anchor: BMAP_ANCHOR_BOTTOM_RIGHT,
        type: BMAP_NAVIGATION_CONTROL_SMALL
      }));
      if (latitude && longitude) {
        var point = new BMap.Point(longitude, latitude);
        map.centerAndZoom(point, 16);
        map.addOverlay(new BMap.Marker(point));
      } else {
        var myGeo = new BMap.Geocoder();
        // 将地址解析结果显示在地图上,并调整地图视野
        myGeo.getPoint(attr.address, function(point) {
          if (point) {
            map.centerAndZoom(point, 16);
            map.addOverlay(new BMap.Marker(point));
          } else {
            alert("您选择地址没有解析到结果!");
          }
        }, "北京市");
      }
    }
  };
})

.directive('lsQrcode', function() {

  return {
    restrict: 'E',
    replace: true,
    scope: {
      content: '@',
      qrwidth: '@',
      qrheight: '@'
    },
    template: '<img></img>',
    link: function(scope, element, attr) {
      var width = parseInt(scope.qrwidth) || 80;
      var height = parseInt(scope.qrheight) || 80;
      var content = scope.content || '';
      var qrcode = new QRCode(element[0], {
        width: width,
        height: height
      });
      qrcode.makeCode(scope.content);
    }
  };
})

.directive('lsImg', function(templateUrlPath) {
  return {
    restrict: 'A',
    compile: function(element, attr) {
      angular.element(element).addClass('ls-animate-fadeout').addClass('ls-loading');
      return function(scope, element, attr) {
        element[0].onload = function(event) {
          angular.element(element).removeClass('ls-loading');
        };
        element[0].onerror = function(event) {
          element[0].src = templateUrlPath + (attr.lsImg || './img/default.png');
        };
      };
    }
  };
})

.directive('lsOpenInBrowser', function($cordovaInAppBrowser) {
  return {
    restrict: 'A',
    link: function(scope, element, attr) {
      angular.element(element).on('click', function(event) {
        event.preventDefault();
        $cordovaInAppBrowser.open(attr.href, '_blank');
      });
    }
  };
})

.directive('lsSrc', function(templateUrlPath) {
  return {
    restrict: 'A',
    link: function(scope, element, attr) {
      element[0].src = templateUrlPath + attr.lsSrc;
    }
  }
})

.directive('lsSubTabs', function() {
  return {
    restrict: 'E',
    replace: true,
    transclude: true,
    scope: {
      currentTab: '='
    },
    templateUrl: 'templates/directives/subtabs.html',
    controller: function($scope, $element, $attrs, $transclude) {
      $scope.switchTab = function(tab) {
        $attrs.currentTab = tab;
      };
    }
  };
})

.directive('lsSubTab', function() {
    return {
      restrict: 'E',
      replace: true,
      scope: {
        index: '@'
      },
      transclude: true,
      template: '<a class="tab-item"><span class="tab-title" ng-transclude></span></a>',
      link: function(scope, element, attr) {
        var el = angular.element(element);
        if (scope.$parent.$parent.currentTab === parseInt(scope.index)) {
          el.addClass('tab-item-active');
        }
        el.on('click', function() {
          el.parent().children().removeClass('tab-item-active');
          el.addClass('tab-item-active');
          scope.$parent.$parent.currentTab = parseInt(scope.index);
          scope.$apply();
        });
      }
    };
  })
  .directive('hideTabBar', function($timeout) {
    var style = angular.element('<style>').html(
      '.has-tabs.no-tabs:not(.has-tabs-top) { bottom: 0; }\n' +
      '.no-tabs.has-tabs-top { top: 44px; }');
    document.body.appendChild(style[0]);
    return {
      restrict: 'A',
      compile: function(element, attr) {
        var tabBar = document.querySelector('.tab-nav');

        return function($scope, $element, $attr) {
          var scroll = $element[0].querySelector('.scroll-content');
          var footer = $element[0].querySelector('.bar-footer');
          $scope.$on('$ionicView.beforeEnter', function(e) {
            tabBar.classList.add('slide-away');
            scroll.classList.add('no-tabs');
            if (footer) {
              footer.classList.add('no-tabs');
            }
          });
          $scope.$on('$ionicView.afterEnter', function(e) {
            scroll.classList.remove('has-tabs');
          });
        };
      }
    };
  })
  .directive('showTabBar', function($timeout) {
    var style = angular.element('<style>').html(
      '.has-tabs.no-tabs:not(.has-tabs-top) { bottom: 0; }\n' +
      '.no-tabs.has-tabs-top { top: 44px; }');
    document.body.appendChild(style[0]);
    return {
      restrict: 'A',
      compile: function(element, attr) {
        var tabBar = document.querySelector('.tab-nav');

        return function($scope, $element, $attr) {
          var scroll = $element[0].querySelector('.scroll-content');

          $scope.$on('$ionicView.beforeEnter', function(e) {
            tabBar.classList.remove('slide-away');
            scroll.classList.remove('no-tabs');
          });
        };
      }
    };
  });
